From: tip-bot for Marc Zyngier <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: graeme@xora.org.uk, marc.zyngier@arm.com, hpa@zytor.com,
jiang.liu@linux.intel.com, linux-kernel@vger.kernel.org,
linux-arm-kernel@lists.infradead.org, jakeo@microsoft.com,
rjw@rjwysocki.net, tomasz.nowicki@linaro.org, tglx@linutronix.de,
hanjun.guo@linaro.org, lorenzo.pieralisi@arm.com,
mingo@kernel.org, jason@lakedaemon.net,
Suravee.Suthikulpanit@amd.com
Subject: [tip:irq/core] irqdomain: Allow irq domain lookup by fwnode
Date: Tue, 13 Oct 2015 10:55:21 -0700 [thread overview]
Message-ID: <tip-130b8c6c8d86075304952241bf2365cea6489df1@git.kernel.org> (raw)
In-Reply-To: <1444737105-31573-4-git-send-email-marc.zyngier@arm.com>
Commit-ID: 130b8c6c8d86075304952241bf2365cea6489df1
Gitweb: http://git.kernel.org/tip/130b8c6c8d86075304952241bf2365cea6489df1
Author: Marc Zyngier <marc.zyngier@arm.com>
AuthorDate: Tue, 13 Oct 2015 12:51:31 +0100
Committer: Thomas Gleixner <tglx@linutronix.de>
CommitDate: Tue, 13 Oct 2015 19:01:23 +0200
irqdomain: Allow irq domain lookup by fwnode
So far, our irq domains are still looked up by device node.
Let's change this and allow a domain to be looked up using
a fwnode_handle pointer.
The existing interfaces are preserved with a couple of helpers.
Signed-off-by: Marc Zyngier <marc.zyngier@arm.com>
Reviewed-and-tested-by: Hanjun Guo <hanjun.guo@linaro.org>
Tested-by: Lorenzo Pieralisi <lorenzo.pieralisi@arm.com>
Cc: <linux-arm-kernel@lists.infradead.org>
Cc: Tomasz Nowicki <tomasz.nowicki@linaro.org>
Cc: Suravee Suthikulpanit <Suravee.Suthikulpanit@amd.com>
Cc: Graeme Gregory <graeme@xora.org.uk>
Cc: Jake Oshins <jakeo@microsoft.com>
Cc: Jiang Liu <jiang.liu@linux.intel.com>
Cc: Jason Cooper <jason@lakedaemon.net>
Cc: Rafael J. Wysocki <rjw@rjwysocki.net>
Link: http://lkml.kernel.org/r/1444737105-31573-4-git-send-email-marc.zyngier@arm.com
Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
---
include/linux/irqdomain.h | 11 +++++++++--
kernel/irq/irqdomain.c | 16 +++++++---------
2 files changed, 16 insertions(+), 11 deletions(-)
diff --git a/include/linux/irqdomain.h b/include/linux/irqdomain.h
index 2f508f4..607c185 100644
--- a/include/linux/irqdomain.h
+++ b/include/linux/irqdomain.h
@@ -183,10 +183,17 @@ struct irq_domain *irq_domain_add_legacy(struct device_node *of_node,
irq_hw_number_t first_hwirq,
const struct irq_domain_ops *ops,
void *host_data);
-extern struct irq_domain *irq_find_matching_host(struct device_node *node,
- enum irq_domain_bus_token bus_token);
+extern struct irq_domain *irq_find_matching_fwnode(struct fwnode_handle *fwnode,
+ enum irq_domain_bus_token bus_token);
extern void irq_set_default_host(struct irq_domain *host);
+static inline struct irq_domain *irq_find_matching_host(struct device_node *node,
+ enum irq_domain_bus_token bus_token)
+{
+ return irq_find_matching_fwnode(node ? &node->fwnode : NULL,
+ bus_token);
+}
+
static inline struct irq_domain *irq_find_host(struct device_node *node)
{
return irq_find_matching_host(node, DOMAIN_BUS_ANY);
diff --git a/kernel/irq/irqdomain.c b/kernel/irq/irqdomain.c
index 1aee5c1..023ab6d 100644
--- a/kernel/irq/irqdomain.c
+++ b/kernel/irq/irqdomain.c
@@ -191,12 +191,12 @@ struct irq_domain *irq_domain_add_legacy(struct device_node *of_node,
EXPORT_SYMBOL_GPL(irq_domain_add_legacy);
/**
* irq_find_matching_host() - Locates a domain for a given device node
* @node: device-tree node of the interrupt controller
* @bus_token: domain-specific data
*/
-struct irq_domain *irq_find_matching_host(struct device_node *node,
- enum irq_domain_bus_token bus_token)
+struct irq_domain *irq_find_matching_fwnode(struct fwnode_handle *fwnode,
+ enum irq_domain_bus_token bus_token)
{
struct irq_domain *h, *found = NULL;
int rc;
@@ -212,12 +212,10 @@ struct irq_domain *irq_find_matching_host(struct device_node *node,
*/
mutex_lock(&irq_domain_mutex);
list_for_each_entry(h, &irq_domain_list, link) {
- struct device_node *of_node;
- of_node = irq_domain_get_of_node(h);
if (h->ops->match)
- rc = h->ops->match(h, node, bus_token);
+ rc = h->ops->match(h, to_of_node(fwnode), bus_token);
else
- rc = ((of_node != NULL) && (of_node == node) &&
+ rc = ((fwnode != NULL) && (h->fwnode == fwnode) &&
((bus_token == DOMAIN_BUS_ANY) ||
(h->bus_token == bus_token)));
@@ -229,7 +227,7 @@ struct irq_domain *irq_find_matching_host(struct device_node *node,
mutex_unlock(&irq_domain_mutex);
return found;
}
-EXPORT_SYMBOL_GPL(irq_find_matching_host);
+EXPORT_SYMBOL_GPL(irq_find_matching_fwnode);
/**
* irq_set_default_host() - Set a "default" irq domain
next prev parent reply other threads:[~2015-10-13 17:56 UTC|newest]
Thread overview: 42+ messages / expand[flat|nested] mbox.gz Atom feed top
2015-10-13 11:51 [PATCH v2 00/17] Divorcing irqdomain and device_node Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 01/17] irqdomain: Use irq_domain_get_of_node() instead of direct field access Marc Zyngier
2015-10-13 17:54 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 02/17] irqdomain: Convert irqdomain->of_node to fwnode Marc Zyngier
2015-10-13 17:55 ` [tip:irq/core] irqdomain: Convert irqdomain-%3Eof_node " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 03/17] irqdomain: Allow irq domain lookup by fwnode Marc Zyngier
2015-10-13 17:55 ` tip-bot for Marc Zyngier [this message]
2015-10-13 11:51 ` [PATCH v2 04/17] irqdomain: Introduce a firmware-specific IRQ specifier structure Marc Zyngier
2015-10-13 17:55 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 05/17] irqchip: Convert all alloc/xlate users from of_node to fwnode Marc Zyngier
2015-10-13 17:56 ` [tip:irq/core] irqchip: Convert all alloc/ xlate " tip-bot for Marc Zyngier
2015-10-14 15:26 ` [PATCH v2 05/17] irqchip: Convert all alloc/xlate " Tomasz Nowicki
2015-10-14 15:31 ` Marc Zyngier
2015-10-14 15:37 ` Tomasz Nowicki
2015-10-13 11:51 ` [PATCH v2 06/17] irqdomain: Introduce irq_create_fwspec_mapping Marc Zyngier
2015-10-13 17:56 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 07/17] irqdomain: Introduce irq_domain_create_{linear,tree} Marc Zyngier
2015-10-13 17:56 ` [tip:irq/core] irqdomain: Introduce irq_domain_create_{linear, tree} tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 08/17] irqdomain: Add a fwnode_handle allocator Marc Zyngier
2015-10-13 17:57 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 09/17] acpi/gsi: Always perform an irq domain lookup Marc Zyngier
2015-10-13 17:57 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 10/17] acpi/gsi: Add acpi_set_irq_model to initialize the GSI layer Marc Zyngier
2015-10-13 17:57 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 11/17] irqchip/gic: Get rid of gic_init_bases() Marc Zyngier
2015-10-13 17:58 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 12/17] irqchip/gic: Switch ACPI support to stacked domains Marc Zyngier
2015-10-13 17:58 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 13/17] irqchip/gic: Kill the xlate method Marc Zyngier
2015-10-13 17:58 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 14/17] acpi/gsi: Cleanup acpi_register_gsi Marc Zyngier
2015-10-13 17:59 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 15/17] irqdomain: Introduce irq_domain_create_hierarchy Marc Zyngier
2015-10-13 17:59 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 16/17] irqdomain/msi: Use fwnode instead of of_node Marc Zyngier
2015-10-13 17:59 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 11:51 ` [PATCH v2 17/17] irqdomain: Documentation updates Marc Zyngier
2015-10-13 18:00 ` [tip:irq/core] " tip-bot for Marc Zyngier
2015-10-13 13:49 ` [PATCH v2 00/17] Divorcing irqdomain and device_node Hanjun Guo
2015-10-13 15:33 ` Hanjun Guo
2015-10-13 15:38 ` Marc Zyngier
2015-10-13 16:39 ` Lorenzo Pieralisi
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-130b8c6c8d86075304952241bf2365cea6489df1@git.kernel.org \
--to=tipbot@zytor.com \
--cc=Suravee.Suthikulpanit@amd.com \
--cc=graeme@xora.org.uk \
--cc=hanjun.guo@linaro.org \
--cc=hpa@zytor.com \
--cc=jakeo@microsoft.com \
--cc=jason@lakedaemon.net \
--cc=jiang.liu@linux.intel.com \
--cc=linux-arm-kernel@lists.infradead.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=lorenzo.pieralisi@arm.com \
--cc=marc.zyngier@arm.com \
--cc=mingo@kernel.org \
--cc=rjw@rjwysocki.net \
--cc=tglx@linutronix.de \
--cc=tomasz.nowicki@linaro.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -191,12 +191,12 @@ struct irq_domain *irq_domain_add_legacy(struct device_node *of_node,
EXPORT_SYMBOL_GPL(irq_domain_add_legacy);
/**
- * irq_find_matching_host() - Locates a domain for a given device node
- * @node: device-tree node of the interrupt controller
+ * irq_find_matching_fwnode() - Locates a domain for a given fwnode
+ * @fwnode: FW descriptor of the interrupt controller
* @bus_token: domain-specific data
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox